summaryrefslogtreecommitdiffstats
path: root/java/sca/modules/interface-java/src/main
diff options
context:
space:
mode:
authormcombellack <mcombellack@13f79535-47bb-0310-9956-ffa450edef68>2009-01-28 14:07:54 +0000
committermcombellack <mcombellack@13f79535-47bb-0310-9956-ffa450edef68>2009-01-28 14:07:54 +0000
commitcd174bad484f3d6f2f755d9fe517b0b37d7f928b (patch)
tree064000c6d9c5f6ee61031848b46e8299f07086ec /java/sca/modules/interface-java/src/main
parent85060ec6b7a53cb76d969e5d30d80538c7f7ccb9 (diff)
TUSCANY-2790 - Updated package names from org.osoa.sca to org.oasisopen.sca and from org.osoa.sca.annotations to org.oasisopen.sca.annotation to reflect the new package names in the OASIS Open SCA specifications.
To do this, I: * Renamed the org.osoa.sca package to org.oasisopen.sca using Eclipse refactoring * Renamed the org.osoa.sca.annotations package to org.oasisopen.sca.annotation using Eclipse refactoring * Did a global search and replace for all remaining instances of the old org.osoa package names and replaced with the new org.oasisopen version Hopefully, I have not missed too many instances of the old package name git-svn-id: http://svn.us.apache.org/repos/asf/tuscany@738490 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'java/sca/modules/interface-java/src/main')
-rw-r--r--java/sca/modules/interface-java/src/main/java/org/apache/tuscany/sca/interfacedef/java/impl/JavaInterfaceIntrospectorImpl.java10
-rw-r--r--java/sca/modules/interface-java/src/main/java/org/apache/tuscany/sca/interfacedef/java/impl/PolicyJavaInterfaceVisitor.java6
2 files changed, 8 insertions, 8 deletions
diff --git a/java/sca/modules/interface-java/src/main/java/org/apache/tuscany/sca/interfacedef/java/impl/JavaInterfaceIntrospectorImpl.java b/java/sca/modules/interface-java/src/main/java/org/apache/tuscany/sca/interfacedef/java/impl/JavaInterfaceIntrospectorImpl.java
index c858d4f71a..c05b21c5ed 100644
--- a/java/sca/modules/interface-java/src/main/java/org/apache/tuscany/sca/interfacedef/java/impl/JavaInterfaceIntrospectorImpl.java
+++ b/java/sca/modules/interface-java/src/main/java/org/apache/tuscany/sca/interfacedef/java/impl/JavaInterfaceIntrospectorImpl.java
@@ -48,10 +48,10 @@ import org.apache.tuscany.sca.interfacedef.java.JavaOperation;
import org.apache.tuscany.sca.interfacedef.java.introspect.JavaInterfaceVisitor;
import org.apache.tuscany.sca.interfacedef.util.JavaXMLMapper;
import org.apache.tuscany.sca.interfacedef.util.XMLType;
-import org.osoa.sca.annotations.Conversational;
-import org.osoa.sca.annotations.EndsConversation;
-import org.osoa.sca.annotations.OneWay;
-import org.osoa.sca.annotations.Remotable;
+import org.oasisopen.sca.annotation.Conversational;
+import org.oasisopen.sca.annotation.EndsConversation;
+import org.oasisopen.sca.annotation.OneWay;
+import org.oasisopen.sca.annotation.Remotable;
/**
* Default implementation of a Java interface introspector.
@@ -100,7 +100,7 @@ public class JavaInterfaceIntrospectorImpl {
javaInterface.setConversational(conversational);
Class<?> callbackClass = null;
- org.osoa.sca.annotations.Callback callback = clazz.getAnnotation(org.osoa.sca.annotations.Callback.class);
+ org.oasisopen.sca.annotation.Callback callback = clazz.getAnnotation(org.oasisopen.sca.annotation.Callback.class);
if (callback != null && !Void.class.equals(callback.value())) {
callbackClass = callback.value();
if (remotable && !callbackClass.isAnnotationPresent(Remotable.class)) {
diff --git a/java/sca/modules/interface-java/src/main/java/org/apache/tuscany/sca/interfacedef/java/impl/PolicyJavaInterfaceVisitor.java b/java/sca/modules/interface-java/src/main/java/org/apache/tuscany/sca/interfacedef/java/impl/PolicyJavaInterfaceVisitor.java
index ed00510a67..bf80bef175 100644
--- a/java/sca/modules/interface-java/src/main/java/org/apache/tuscany/sca/interfacedef/java/impl/PolicyJavaInterfaceVisitor.java
+++ b/java/sca/modules/interface-java/src/main/java/org/apache/tuscany/sca/interfacedef/java/impl/PolicyJavaInterfaceVisitor.java
@@ -31,11 +31,11 @@ import org.apache.tuscany.sca.interfacedef.java.introspect.JavaInterfaceVisitor;
import org.apache.tuscany.sca.policy.Intent;
import org.apache.tuscany.sca.policy.PolicyFactory;
import org.apache.tuscany.sca.policy.PolicySet;
-import org.osoa.sca.annotations.PolicySets;
-import org.osoa.sca.annotations.Requires;
+import org.oasisopen.sca.annotation.PolicySets;
+import org.oasisopen.sca.annotation.Requires;
/**
* Processes an {@link org.osoa.sca.annotations.Requires} annotation
*
* @version $Rev$ $Date$
*/
@@ -31,11 +31,11 @@ import org.apache.tuscany.sca.interfacedef.java.introspect.JavaInterfaceVisitor;
/**
- * Processes an {@link org.osoa.sca.annotations.Requires} annotation
+ * Processes an {@link org.oasisopen.sca.annotation.Requires} annotation
*
* @version $Rev$ $Date$